@@ -1,7 +1,7 @@
 daarem <- function(par, fixptfn, objfn, ..., control=list()) {
 
   control.default <- list(maxiter=2000, order=5, tol=1.e-08, mon.tol=0.01, cycl.mon.tol=0.0, kappa=25, 
-                          alpha=1.2, resid.tol=0.95, convtype="param")
+                          alpha=1.2, resid.tol=0.95, convtype="param", intermed=FALSE)
   namc <- names(control)
   if (!all(namc %in% names(control.default))) {
     stop("unknown names in control: ", namc[!(namc %in% names(control.default))])
@@ -20,17 +20,21 @@ daarem <- function(par, fixptfn, objfn, ..., control=list()) {
   } else if(control$convtype=="objfn") {
       check.par.resid <- FALSE
   }
-
+  intermed <- control$intermed
+  
   num.params <- length(par)
   nlag <- min(control$order, ceiling(num.params/2))
 
+ 
   if(!missing(objfn)) {
-      ans <- daarem_base_objfn(par, fixptfn, objfn, maxiter, tol, mon.tol, 
-                               cycl.mon.tol, a1, kappa, num.params, nlag, 
-                               check.par.resid, ...) 
+      ans <- daarem_base_objfn(par=par, fixptfn=fixptfn, objfn=objfn, maxiter=maxiter, 
+                               tol=tol, mon.tol=mon.tol, cycl.mon.tol=cycl.mon.tol, a1=a1, 
+                               kappa=kappa, num.params=num.params, nlag=nlag, 
+                               check.par.resid=check.par.resid, intermed=intermed, ...) 
   } else {
-      ans <- daarem_base_noobjfn(par, fixptfn, maxiter, tol, resid.tol, 
-                                 a1, kappa, num.params, nlag, ...) 
+      ans <- daarem_base_noobjfn(par=par, fixptfn=fixptfn, maxiter=maxiter, tol=tol, 
+                                 resid.tol=resid.tol, a1=a1, kappa=kappa, 
+                                 num.params=num.params, nlag=nlag, intermed=intermed, ...) 
   }
   if(!ans$convergence) {
      warning("Algorithm did not converge")
